@@ -8,12 +8,18 @@ from famegui.agent_controller import AgentController
 
 
 class DialogNewContract(QDialog):
-    def _configure_line_edit(self, line_edit: QLineEdit):
+    def _configure_line_edit_for_unsigned_int(self, line_edit: QLineEdit):
         line_edit.setText("0")
         regex_uint64 = QtCore.QRegExp("\\d{1,20}")
         line_edit.setValidator(QtGui.QRegExpValidator(regex_uint64))
         line_edit.textChanged.connect(self._update_ok_button_status)
 
+    def _configure_line_edit_for_signed_int(self, line_edit: QLineEdit):
+        line_edit.setText("0")
+        regex_uint64 = QtCore.QRegExp("-?\\d{1,20}")
+        line_edit.setValidator(QtGui.QRegExpValidator(regex_uint64))
+        line_edit.textChanged.connect(self._update_ok_button_status)
+
     def __init__(self, sender: AgentController, receiver: AgentController, schema: models.Schema, parent=None):
         QDialog.__init__(self, parent)
         self._ui = Ui_DialogNewContract()
@@ -32,8 +38,9 @@ class DialogNewContract(QDialog):
             '</body></html>').format(sender.id_str, sender.type_name, receiver.id_str, receiver.type_name))
 
         # accept uint64 numbers as specified in protobuf schema
-        self._configure_line_edit(self._ui.lineDeliveryInterval)
-        self._configure_line_edit(self._ui.lineFirstDelivery)
+        self._configure_line_edit_for_unsigned_int(
+            self._ui.lineDeliveryInterval)
+        self._configure_line_edit_for_signed_int(self._ui.lineFirstDelivery)
 
         # fill possible products to select based on the sender SchemaAgentType
         sender_type = schema.agent_type_from_name(sender.type_name)
