@@ -22,12 +22,13 @@ from famegui.protobuf_generation import generate_protobuf_from_scenario_yaml_fil
 
 class PropertyTreeItem(QtWidgets.QTreeWidgetItem):
     def __init__(self, parent, name, value):
-        QtWidgets.QTreeWidgetItem.__init__(self, parent, [name, value])
+        super().__init__(parent, [name, value])
         self.setFlags(self.flags() | QtCore.Qt.ItemIsEditable)
 
     def setData(self, column, role, value):
         """ Override QTreeWidgetItem.setData() """
         if (role == QtCore.Qt.EditRole):
+            # review: Can we remove this code? It seems to be unused at the moment and not necessary.
             # logging.info("new value: {}".format(value))
             pass
 
@@ -36,7 +37,8 @@ class PropertyTreeItem(QtWidgets.QTreeWidgetItem):
 
 class MainWindow(QMainWindow):
     def __init__(self, working_dir: AppWorkingDir):
-        super(MainWindow, self).__init__()
+        super().__init__()
+
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
         self._working_dir = working_dir
@@ -52,17 +54,19 @@ class MainWindow(QMainWindow):
         logging.debug("initializing main window UI")
         # create an attach the scene
         self._graph_view = ScenarioGraphView(self)
-        self._graph_view.setSceneRect(0, 0, 2000, 2000)
+        self._graph_view.setSceneRect(self._controller.compute_scene_rect())
         self.ui.graphicsView.setScene(self._graph_view)
         # customize main window
         self.ui.labelUserName.setText(getpass.getuser())
         self.ui.graphicsView.setBackgroundBrush(QtGui.QColor(230, 230, 230))
         self.setWindowTitle(
             QtWidgets.QApplication.instance().applicationDisplayName())
+        # allowed zoom range
+        self.ui.sliderZoomFactor.setRange(10, 100)
         # status bar
         self._status_label_icon = QtWidgets.QLabel()
         self.statusBar().addWidget(self._status_label_icon)
-        # project struture tree view
+        # project structure tree view
         self.ui.treeProjectStructure.setSelectionMode(
             QtWidgets.QAbstractItemView.SingleSelection)
         self.ui.treeProjectStructure.setColumnCount(1)
@@ -79,7 +83,7 @@ class MainWindow(QMainWindow):
             QtWidgets.QAbstractItemView.NoEditTriggers)
 
     def _connect_actions(self):
-        logging.debug("conecting main window actions")
+        logging.debug("connecting main window actions")
         # new
         self.ui.actionNewProject.triggered.connect(self.new_project)
         # open
@@ -114,6 +118,10 @@ class MainWindow(QMainWindow):
             self._on_tree_view_current_item_changed)
         self.ui.lineFilterPattern.textChanged.connect(
             self._filter_pattern_changed)
+        self._graph_view.zoom_in_requested.connect(
+            lambda: self.ui.sliderZoomFactor.setValue(self.ui.sliderZoomFactor.value() + 10))
+        self._graph_view.zoom_out_requested.connect(
+            lambda: self.ui.sliderZoomFactor.setValue(self.ui.sliderZoomFactor.value() - 10))
         # controller
         self._controller.project_properties.changed.connect(
             self._on_scenario_status_changed)
@@ -151,6 +159,7 @@ class MainWindow(QMainWindow):
             new_agent = dlg.make_new_agent(
                 self._controller.generate_new_agent_id())
             self._controller.add_new_agent(new_agent, x, y)
+            self._graph_view.setSceneRect(self._controller.compute_scene_rect())
 
     def _on_contract_creation_requested(self, sender_id: int, receiver_id: int):
         sender = self._controller.agent_from_id(sender_id)
@@ -220,6 +229,7 @@ class MainWindow(QMainWindow):
         self.ui.treeProjectStructure.addTopLevelItem(item)
 
     def _on_agent_added(self, agent_ctrl: AgentController):
+        logging.debug("agent_added: {}".format(agent_ctrl.id_str))
         self._graph_view.add_agent(agent_ctrl)
         self._create_agent_tree_item(agent_ctrl)
 
@@ -302,6 +312,7 @@ class MainWindow(QMainWindow):
                 return False
 
         self._controller.save_to_file(file_path)
+        self._graph_view.setSceneRect(self._controller.compute_scene_rect())
         return True
 
     def close_project(self) -> bool:
