@@ -1,6 +1,5 @@
 # schema
-from .schema_agent_type_field_type import FieldType, SchemaAgentTypeFieldType
-from .schema_agent_type_field import SchemaAgentTypeField
+from .schema_attribute import AttributeType, SchemaAttribute
 from .schema_agent_type import SchemaAgentType
 from .schema import Schema
 from .schema_loader import SchemaLoader
@@ -8,5 +7,6 @@ from .schema_loader import SchemaLoader
 from .agent_graph_layout import layout_agents
 from .agent import Agent
 from .contract import Contract
+from .scenario_properties import ScenarioProperties
 from .scenario import Scenario
 from .scenario_loader import ScenarioLoader
