@@ -7,6 +7,9 @@ class Contract:
         if sender_id == receiver_id:
             raise ValueError(
                 "sender and receiver can't have the same id {}".format(sender_id))
+        if delivery_interval_in_steps < 0:
+            raise ValueError(
+                "delivery interval steps must be a positive integer")
         self._sender_id = sender_id
         self._receiver_id = receiver_id
         self._product_name = product_name
