@@ -55,7 +55,7 @@ class ContractGraphItem(QtWidgets.QGraphicsItem):
         [dest_x, dest_y] = dest_center.toTuple()
         distance = math.sqrt((src_x - dest_x)**2 + (src_y - dest_y)**2)
         if distance <= radius * 2:
-            logging.info("items are too close to draw a line")
+            logging.warning("items are too close to draw a line")
             return
 
         distance_x = dest_x - src_x
@@ -115,6 +115,9 @@ class ContractGraphItem(QtWidgets.QGraphicsItem):
 class AgentGraphItem(QtWidgets.QGraphicsItem):
     Type = QGraphicsItem.UserType + 2
 
+    # use a lambda rather than a Qt signal because we don't inherit from QObject
+    position_changed = lambda self, x, y: None
+
     def __init__(self, agent_id, label, color):
         QGraphicsItem.__init__(self)
         # public
@@ -152,6 +155,7 @@ class AgentGraphItem(QtWidgets.QGraphicsItem):
         if change == QGraphicsItem.ItemPositionChange:
             for edge in self.edgeList:
                 edge().adjust()
+            self.position_changed(self.x(), self.y())
         return QGraphicsItem.itemChange(self, change, value)
 
     def paint(self, painter, option, widget=None):
